@@ -11,7 +11,7 @@ use Getopt::Std;
 use Lingua::Translit;
 
 # Version.
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -20,6 +20,14 @@ sub new {
 	# Create object.
 	my $self = bless {}, $class;
 
+	# Object.
+	return $self;
+}
+
+# Run script.
+sub run {
+	my $self = shift;
+
 	# Process arguments.
 	$self->{'_opts'} = {
 		'h' => 0,
@@ -39,13 +47,7 @@ sub new {
 	}
 	$self->{'_string'} = $ARGV[0];
 
-	# Object.
-	return $self;
-}
-
-# Run script.
-sub run {
-	my $self = shift;
+	# Run.
 	my $ret;
 	eval {
 		my $tr = Lingua::Translit->new($self->{'_opts'}->{'t'});
@@ -102,12 +104,10 @@ App::Translit::String - Perl class for translit-string application.
 
 =head1 ERRORS
 
- new():
-         From Class::Utils:
-                 Unknown parameter '%s'.
-
  run():
          Cannot transliterate string.
+                 Error: %s
+         No reverse transliteration.
 
 =head1 EXAMPLE1
 
@@ -170,6 +170,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
